<template>
    <div class="app-container">
        <div style="margin: 15px">
            <span class="span-filter-label">单号</span>
            <el-input style="width: 140px" v-model="filter.filter.code" ></el-input>
            <span class="span-filter-label">隐患等级</span>
            <el-select v-model="filter.filter.level" clearable  @clear="clearLevel" placeholder="请选择">
                <el-option
                    v-for="item in levels"
                    :key="item.key"
                    :label="item.value"
                    :value="item.key">
                </el-option>
            </el-select>
            <span class="span-filter-label">整改人</span>
            <el-input style="width: 160px" v-model="filter.filter.rectifierName"></el-input>
            <el-button class="filter-item" style="margin-left: 10px;" type="primary" icon="el-icon-search"
                       @click="queryHandle"/>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="tableData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column type="index" label="序号" align="center" width="80"/>
                <el-table-column label="单号" prop="code" align="center" />
                <el-table-column label="状态" prop="status" align="center" >
                    <template slot-scope="scope">
                        <span >{{scope.row.status}}</span>
                        <span v-if="new Date(scope.row.rectifydeadline) < new Date() && scope.row.status  !== '已完成'" class="overdue-img">逾期</span>
                    </template>
                </el-table-column>
                <el-table-column label="隐患等级" prop="level" align="center" >
                    <template slot-scope="scope">
                        <el-tag :type="scope.row.level == '紧急'?'danger':'warning'">{{scope.row.level}}</el-tag>
                    </template>
                </el-table-column>
                <el-table-column label="上报人" prop="requestor" align="center" />
                <el-table-column label="上报时间" prop="createtime" align="center" />
                <el-table-column label="整改人" prop="rectifier" align="center" />
                <el-table-column label="整改期限"   prop="rectifydeadline" align="center" >
                    <template slot-scope="scope">
                        <span v-bind:class="{'overdue':new Date(scope.row.rectifydeadline) < new Date() && scope.row.status  !== '已完成'}">{{scope.row.rectifydeadline}}
                        </span>
                    </template>
                </el-table-column>
                <el-table-column label="整改时间" prop="rectifytime" align="center" />


                <el-table-column label="操作" align="center" width="240" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button  type="text" @click="viewHandle(scope.row)">查看</el-button>
                        <el-button  type="text" @click="acceptHandle(scope.row)" v-if="scope.row.status === '整改待验收'">验收</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="filter.pageIndex"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="filter.pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
        </div>

        <report-view ref="reportView"></report-view>
        <accept-dialog ref="acceptDialog" @refresh="hiddenDangerList"></accept-dialog>


        <div style="clear: both;"></div>
    </div>
</template>

<script>
import { checkBtnPermission} from "@/utils/permission";
import { hiddenDangerAcceptList} from '@/api/hiddenDanger';
import reportView from "./reportView/reportView";
import acceptDialog from "./acceptDialog/acceptDialog";

export default {
    name: "confirm",
  components: {
    reportView,
    acceptDialog,
  },
    data() {
      return {
        recordTotal: 0,
        tableKey: 0,
        tableData:[],
        listLoading: true,
        levels:[
          {"key":"URGENT","value":"紧急"},
          {"key":"COMMON","value":"一般"},
        ],
        dataForm: {
          id:'',
          note: '',
          level:'',
          rejectnote:'',
        },
        filter:{
          pageIndex:1,
          pageSize:10,
          filter:{
            code:'',
            level:null,
            rectifierName:'',
          }
        }
      }
    },
    created() {
      this.hiddenDangerList();
    },

    methods: {
        queryHandle: function () {
            this.filter.pageIndex = 1
            this.hiddenDangerList()
        },


        viewHandle: function (row) {
          this.$refs.reportView.showDialog("查看",row)
        },

        acceptHandle(row){
            this.$refs.acceptDialog.showDialog(row)
        }  ,

        handleSizeChange: function (val) {
            this.filter.pageSize = val
            this.filter.pageIndex = 1
            this.hiddenDangerList()
        },
        handleCurrentChange: function (val) {
            this.filter.pageIndex = val
            this.hiddenDangerList()
        },
        getBtnPermission(btnType) {
            return checkBtnPermission(this.userType, btnType)
        },

        downloadHandle(fileurl){
            window.open(fileurl, '_blank');
        },


      handleChange(file, fileList) {
        this.fileList = fileList
      },

      hiddenDangerList(){
          this.listLoading = true
          hiddenDangerAcceptList(this.filter)
              .then(res=>{
                if (res.data.code === '200') {
                  this.tableData =  res.data.result.records
                  this.recordTotal =  res.data.result.total
                }
                else{
                    this.$message({message: res.data.message, type: 'warning'});
                }
              })
              .catch(err=>{
                  console.log(err)
                  this.$message({message: '接口错误', type: 'warning'});
              })
              .finally(()=>{
                  this.listLoading = false
              })
      },
      clearLevel(){
            this.filter.filter.level = null
      }


    }
}
</script>

<style scoped>
    .overdue{
        color: red;
    }
    .overdue-img{
        position: fixed;
        background-color: #f56c6c;
        border-radius: 4px;
        color: #fff;
        display: inline-block;
        font-size: 12px;
        height: 21px;
        line-height: 18px;
        text-align: center;
        white-space: nowrap;
        border: 1px solid #fff;
        transform: scale(0.8);
        padding: 1px 3px 0 3px;

    }

</style>
